@@ -34,14 +34,15 @@
 # POSSIBILITY OF SUCH DAMAGE.
 
 import sys
+import numpy as np
 from phonopy import Phonopy
 from phonopy import PhonopyGruneisen
-from phonopy.interface import read_crystal_structure, get_default_cell_filename
+from phonopy.interface import (read_crystal_structure,
+                               get_default_cell_filename,
+                               get_default_physical_units)
 from phonopy.file_IO import (parse_FORCE_SETS, parse_BORN,
                              parse_FORCE_CONSTANTS, read_force_constants_hdf5)
-from phonopy.units import (VaspToTHz, Wien2kToTHz, AbinitToTHz, PwscfToTHz,
-                           CrystalToTHz)
-import numpy as np
+from phonopy.units import VaspToTHz
 
 def fracval(frac):
     if frac.find('/') == -1:
@@ -68,14 +69,14 @@ def get_phonon(cell_filename,
                dim,
                primitive_matrix=np.eye(3),
                born_filename=None,
-               factor=VaspToTHz,
+               physical_units=None,
                interface_mode='vasp',
                symprec=1e-5):
     cell = get_cell(cell_filename, interface_mode)
     phonon = Phonopy(cell,
                      dim,
                      primitive_matrix=primitive_matrix,
-                     factor=factor,
+                     factor=physical_units['factor'],
                      symprec=symprec)
     force_sets = parse_FORCE_SETS(filename=force_sets_filename)
     phonon.set_displacement_dataset(force_sets)
@@ -84,6 +85,8 @@ def get_phonon(cell_filename,
         nac_params = parse_BORN(phonon.get_primitive(),
                                 filename=born_filename,
                                 symprec=symprec)
+        if nac_params['factor'] == None:
+            nac_params['factor'] = physical_units['nac_factor']
         phonon.set_nac_params(nac_params)
     phonon.set_dynamical_matrix()
     return phonon
@@ -93,7 +96,7 @@ def get_phonon_from_force_constants(cell_filename,
                                     dim,
                                     primitive_matrix=np.eye(3),
                                     born_filename=None,
-                                    factor=VaspToTHz,
+                                    physical_units=None,
                                     interface_mode='vasp',
                                     symprec=1e-5,
                                     is_hdf5=False):
@@ -101,7 +104,7 @@ def get_phonon_from_force_constants(cell_filename,
     phonon = Phonopy(cell,
                      dim,
                      primitive_matrix=primitive_matrix,
-                     factor=factor,
+                     factor=physical_units['factor'],
                      symprec=symprec)
     if is_hdf5:
         force_constants = read_force_constants_hdf5(
@@ -114,6 +117,8 @@ def get_phonon_from_force_constants(cell_filename,
         nac_params = parse_BORN(phonon.get_primitive(),
                                 filename=born_filename,
                                 symprec=symprec)
+        if nac_params['factor'] == None:
+            nac_params['factor'] = physical_units['nac_factor']
         phonon.set_nac_params(nac_params)
     phonon.set_dynamical_matrix()
     return phonon
@@ -142,6 +147,7 @@ parser.set_defaults(
     pwscf_mode=False,
     sampling_mesh=None,
     save_graph=False,
+    siesta_mode=False,
     supercell_dimension=None,
     symprec=1e-5,
     title=None,
@@ -211,6 +217,8 @@ parser.add_option("--readfc", dest="reads_force_constants",
 parser.add_option("-s", "--save", dest="save_graph",
                   action="store_true",
                   help="Save plot data in pdf")
+parser.add_option("--siesta", dest="siesta_mode",
+                  action="store_true", help="Invoke Siesta mode")
 parser.add_option("-t", "--title", dest="title", action="store",
                   type="string", help="Title of plot")
 parser.add_option("--tmax", dest="tmax", type="float",
@@ -266,33 +274,27 @@ else:
 
 
 #
-# Phonopy interface mode
-#
-# Physical units: energy,  distance,  atomic mass, force
-# vasp          : eV,      Angstrom,  AMU,         eV/Angstrom
-# wien2k        : Ry,      au,        AMU,         mRy/au
-# pwscf         : Ry,      au,        AMU,         Ry/au
-# abinit        : hartree, au(=bohr), AMU,         eV/Angstrom
-# CRYSTAL       : eV,      Angstrom,  AMU,         eV/Angstrom
+# Phonopy gruneisen interface mode
 #
 if options.wien2k_mode:
     interface_mode = 'wien2k'
-    factor = Wien2kToTHz
 elif options.abinit_mode:
     interface_mode = 'abinit'
-    factor = AbinitToTHz
 elif options.pwscf_mode:
     interface_mode = 'pwscf'
-    factor = PwscfToTHz
+elif options.elk_mode:
+    interface_mode = 'elk'
+elif options.siesta_mode:
+    interface_mode = 'siesta'
 elif options.crystal_mode:
     interface_mode = 'crystal'
-    factor = CrystalToTHz
 else:
     interface_mode = 'vasp'
-    factor = VaspToTHz
+physical_units = get_default_physical_units(interface_mode)
+
 
 if options.factor is not None:
-    factor = options.factor
+    physical_units['factor'] = options.factor
     
 if options.cell_filename:
     cell_filename = options.cell_filename
@@ -316,7 +318,7 @@ for i in range(3):
                 dim,
                 primitive_matrix=primitive_axis,
                 born_filename=born_filename,
-                factor=factor,
+                physical_units=physical_units,
                 interface_mode=interface_mode,
                 symprec=options.symprec,
                 is_hdf5=True)
@@ -327,7 +329,7 @@ for i in range(3):
                 dim,
                 primitive_matrix=primitive_axis,
                 born_filename=born_filename,
-                factor=factor,
+                physical_units=physical_units,
                 interface_mode=interface_mode,
                 symprec=options.symprec)
         phonons.append(phonon)
@@ -337,7 +339,7 @@ for i in range(3):
                             dim,
                             primitive_matrix=primitive_axis,
                             born_filename=born_filename,
-                            factor=factor,
+                            physical_units=physical_units,
                             interface_mode=interface_mode,
                             symprec=options.symprec)
         phonons.append(phonon)
